@@ -482,6 +482,54 @@ class OpenedTables(StatuBase):
     """
     statu_name="Opened_Tables"
 
+class QcacheFreeBlocks(StatuBase):
+    """
+    The number of free memory blocks in the query cache
+    """
+    statu_name="Qcache_free_blocks"
+
+class QcacheFreeMemory(StatuBase):
+    """
+    The amount of free memory for the query cache
+    """
+    statu_name="Qcache_free_memory"
+
+class QcacheHits(StatuBase):
+    """
+    The number of query cache hits
+    """
+    statu_name="Qcache_hits"
+
+class QcacheInserts(StatuBase):
+    """
+    The number of queries added to the query cache.
+    """
+    statu_name="Qcache_inserts"
+
+class QcacheLowmemPrunes(StatuBase):
+    """
+    The number of queries that were deleted from the query cache because of low memory.
+    """
+    statu_name="Qcache_lowmem_prunes"
+
+class QcacheNotCached(StatuBase):
+    """
+    The number of noncached queries (not cacheable, or not cached due to the query_cache_type setting).
+    """
+    statu_name="Qcache_not_cached"
+
+class QcacheQueriesInCache(StatuBase):
+    """
+    The number of queries registered in the query cache.
+    """
+    statu_name="Qcache_queries_in_cache"
+
+class QcacheTotalBlocks(StatuBase):
+    """
+    The total number of blocks in the query cache.
+    """
+    statu_name="Qcache_total_blocks"
+
 class TableOpenCacheOverflows(StatuBase):
     """
     The number of overflows for the open tables cache. This is the number of times, 
